@@ -1,4 +1,5 @@
-( function ( $ ) {
+/* eslint-disable no-jquery/no-global-selector */
+( function () {
 	'use strict';
 
 	// If MathPlayer is installed we show the MathML rendering.
@@ -16,4 +17,4 @@
 			this.src = this.src.replace( 'mode=mathml', 'mode=mathml-png' );
 		} );
 	}
-}( jQuery ) );
+}() );
