@@ -8,7 +8,10 @@
  *
  * @file
  */
+
+use MediaWiki\Extension\Math\InputCheck\RestbaseChecker;
 use MediaWiki\Logger\LoggerFactory;
+use Psr\Log\LoggerInterface;
 
 /**
  * Abstract base class with static methods for rendering the <math> tags using
@@ -62,8 +65,10 @@ abstract class MathRenderer {
 	protected $inputType = 'tex';
 	/** @var MathRestbaseInterface used for checking */
 	protected $rbi;
-	/** @var array with rendering warnings*/
+	/** @var array with rendering warnings */
 	protected $warnings;
+	/** @var LoggerInterface */
+	private $logger;
 
 	/**
 	 * Constructs a base MathRenderer
@@ -103,6 +108,7 @@ abstract class MathRenderer {
 		// be centered in a new line, or just in be displayed in the current line.
 		$this->userInputTex = $tex;
 		$this->tex = $tex;
+		$this->logger = LoggerFactory::getInstance( 'Math' );
 	}
 
 	/**
@@ -334,7 +340,7 @@ abstract class MathRenderer {
 	public function writeToDatabase( $dbw = null ) {
 		# Now save it back to the DB:
 		if ( !wfReadOnly() ) {
-			LoggerFactory::getInstance( 'Math' )->debug( 'Store entry for $' . $this->tex .
+			$this->logger->debug( 'Store entry for $' . $this->tex .
 				'$ in database (hash:' . $this->getMd5() . ')' );
 			$outArray = $this->dbOutArray();
 			$mathTableName = $this->getMathTableName();
@@ -348,7 +354,7 @@ abstract class MathRenderer {
 
 					$dbw->update( $mathTableName, $outArray,
 						[ 'math_inputhash' => $inputHash ], $fname );
-					LoggerFactory::getInstance( 'Math' )->debug(
+					$this->logger->debug(
 						'Row updated after db transaction was idle: ' .
 						var_export( $outArray, true ) . " to database" );
 				} );
@@ -359,12 +365,12 @@ abstract class MathRenderer {
 					$dbw = $dbw ?: wfGetDB( DB_MASTER );
 
 					$dbw->insert( $mathTableName, $outArray, $fname, [ 'IGNORE' ] );
-					LoggerFactory::getInstance( 'Math' )->debug(
+					$this->logger->debug(
 						'Row inserted after db transaction was idle ' .
 						var_export( $outArray, true ) . " to database" );
 					if ( $dbw->affectedRows() == 0 ) {
 						// That's the price for the delayed update.
-						LoggerFactory::getInstance( 'Math' )->warning(
+						$this->logger->warning(
 							'Entry could not be written. Might be changed in between.' );
 					}
 				} );
@@ -438,14 +444,13 @@ abstract class MathRenderer {
 	 * @return bool
 	 */
 	public function writeCache() {
-		$logger = LoggerFactory::getInstance( 'Math' );
-		$logger->debug( 'Writing of cache requested.' );
+		$this->logger->debug( 'Writing of cache requested.' );
 		if ( $this->isChanged() ) {
-			$logger->debug( 'Change detected. Perform writing.' );
+			$this->logger->debug( 'Change detected. Perform writing.' );
 			$this->writeToDatabase();
 			return true;
 		} else {
-			$logger->debug( "Nothing was changed. Don't write to database." );
+			$this->logger->debug( "Nothing was changed. Don't write to database." );
 			return false;
 		}
 	}
@@ -555,7 +560,7 @@ abstract class MathRenderer {
 		if ( $refererHeader ) {
 			parse_str( parse_url( $refererHeader, PHP_URL_QUERY ), $refererParam );
 			if ( isset( $refererParam['action'] ) && $refererParam['action'] === 'purge' ) {
-				LoggerFactory::getInstance( 'Math' )->debug( 'Re-Rendering on user request' );
+				$this->logger->debug( 'Re-Rendering on user request' );
 				return true;
 			}
 		}
@@ -633,7 +638,6 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 *
 	 * @return string TeX the original tex string specified by the user
 	 */
 	public function getUserInputTex() {
@@ -658,7 +662,6 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 *
 	 * @param string $svg
 	 */
 	public function setSvg( $svg ) {
@@ -719,7 +722,7 @@ abstract class MathRenderer {
 	 * @return bool
 	 */
 	protected function doCheck() {
-		$checker = new MathInputCheckRestbase( $this->tex, $this->getInputType(), $this->rbi );
+		$checker = new RestbaseChecker( $this->tex, $this->getInputType(), $this->rbi );
 		try {
 			if ( $checker->isValid() ) {
 				$this->setTex( $checker->getValidTex() );
